﻿using Syncfusion.SfChart.XForms;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Runtime.CompilerServices;

using Xamarin.Forms;

namespace charttest
{
    public class App : Application, INotifyPropertyChanged
    {
        ObservableCollection<ListItem> _feed;
        public ObservableCollection<ListItem> Feed
        {
            get { return _feed; }
            set
            {
                _feed = value;
                OnPropertyChanged();
            }
        }
        new public event PropertyChangedEventHandler PropertyChanged;
        public App()
        {
            BindingContext = this;

            var listview = new ListView();
            listview.SetBinding(ListView.ItemsSourceProperty, "Feed");
            listview.ItemTemplate = new DataTemplate(typeof(ListCell));
            var list = new ObservableCollection<ListItem>();
            list.Add(new ListItem());
            Feed = list;

            MainPage = new ContentPage()
            {
                Content = listview
            };
            MainPage.Padding = new Thickness(0, 20, 0, 0);
        }

        protected override void OnStart()
        {
            // Handle when your app starts
        }

        protected override void OnSleep()
        {
            // Handle when your app sleeps
        }

        protected override void OnResume()
        {
            // Handle when your app resumes
        }

        protected override void OnPropertyChanged([CallerMemberName] string propertyName = null)
        {
            PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(propertyName));
        }
    }

    public class ListCell : ViewCell
    {
        protected override void OnBindingContextChanged()
        {
            base.OnBindingContextChanged();
            var item = BindingContext as ListItem;

            var cellGrid = new Grid
            {
                BackgroundColor = Color.Transparent,
                RowSpacing = 0,
                ColumnSpacing = 0,
                RowDefinitions =
                {
                    new RowDefinition {Height = new GridLength(1, GridUnitType.Star) },
                    new RowDefinition {Height = new GridLength(1, GridUnitType.Star) },
                    new RowDefinition {Height = new GridLength(1, GridUnitType.Star) },
                    new RowDefinition {Height = new GridLength(1, GridUnitType.Star) },
                    new RowDefinition {Height = new GridLength(1, GridUnitType.Star) },
                    new RowDefinition {Height = new GridLength(1, GridUnitType.Star) },
                    new RowDefinition {Height = new GridLength(1, GridUnitType.Star) },
                    new RowDefinition {Height = new GridLength(1, GridUnitType.Star) },
                    new RowDefinition {Height = new GridLength(1, GridUnitType.Star) },
                    new RowDefinition {Height = new GridLength(1, GridUnitType.Star) },
                    new RowDefinition {Height = new GridLength(1, GridUnitType.Star) },

                },
                ColumnDefinitions =
                {
                    new ColumnDefinition {Width = new GridLength(1, GridUnitType.Star) },
                }
            };
            cellGrid.Children.Add(new MakeChart(item.Data) as View, 0, 0);
               View = cellGrid;                  //<--- this line won't display the chart
            // View = new MakeChart(item.Data);    //<--- this line will display the chart
        }

        public class MakeChart : ContentView
        {
            public MakeChart(ObservableCollection<ChartDataPoint> points)
            {
                var chart = new SfChart();
                var primaryAxis = new CategoryAxis();
                primaryAxis.IsVisible = false;
                chart.PrimaryAxis = primaryAxis;
                var secondaryAxis = new NumericalAxis();
                secondaryAxis.IsVisible = false;
                chart.SecondaryAxis = secondaryAxis;

                var data = points;
                var lineSeries = new LineSeries()
                {
                    Color = Color.FromHex("228BD0"),
                    ItemsSource = data,
                };
                chart.Series.Add(lineSeries);
                Content = chart;
            }
        }
    }

    public class DataModel
    {

        public ObservableCollection<ChartDataPoint> HighTemperature { get; set; }

        public DataModel()
        {

            HighTemperature = new ObservableCollection<ChartDataPoint>();

            HighTemperature.Add(new ChartDataPoint("Jan", 42));
            HighTemperature.Add(new ChartDataPoint("Feb", 44));
            HighTemperature.Add(new ChartDataPoint("Mar", 53));
            HighTemperature.Add(new ChartDataPoint("Apr", 64));
            HighTemperature.Add(new ChartDataPoint("May", 75));
            HighTemperature.Add(new ChartDataPoint("Jun", 83));
            HighTemperature.Add(new ChartDataPoint("Jul", 87));
            HighTemperature.Add(new ChartDataPoint("Aug", 84));
            HighTemperature.Add(new ChartDataPoint("Sep", 78));
            HighTemperature.Add(new ChartDataPoint("Oct", 67));
            HighTemperature.Add(new ChartDataPoint("Nov", 55));
            HighTemperature.Add(new ChartDataPoint("Dec", 45));
        }
    }
    public class ListItem
    {
        public string Title { get; set; }
        public ObservableCollection<ChartDataPoint> Data
        {
            get { return new DataModel().HighTemperature; }
        }
    }

}
